@@ -200,28 +200,26 @@ gda_data_model_row_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
-		if (type == 0) {
-			static GTypeInfo info = {
-				sizeof (GdaDataModelRowClass),
-				(GBaseInitFunc) NULL,
-				(GBaseFinalizeFunc) NULL,
-				(GClassInitFunc) gda_data_model_row_class_init,
-				NULL, NULL,
-				sizeof (GdaDataModelRow),
-				0,
-				(GInstanceInitFunc) gda_data_model_row_init
-			};
-			
-			static const GInterfaceInfo data_model_info = {
-				(GInterfaceInitFunc) gda_data_model_row_data_model_init,
-				NULL,
-				NULL
-			};
-
-			type = g_type_register_static (PARENT_TYPE, "GdaDataModelRow", &info, G_TYPE_FLAG_ABSTRACT);
-			g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
-		}
+	if (G_UNLIKELY (type == 0)) {
+		static GTypeInfo info = {
+			sizeof (GdaDataModelRowClass),
+			(GBaseInitFunc) NULL,
+			(GBaseFinalizeFunc) NULL,
+			(GClassInitFunc) gda_data_model_row_class_init,
+			NULL, NULL,
+			sizeof (GdaDataModelRow),
+			0,
+			(GInstanceInitFunc) gda_data_model_row_init
+		};
+		
+		static const GInterfaceInfo data_model_info = {
+			(GInterfaceInitFunc) gda_data_model_row_data_model_init,
+			NULL,
+			NULL
+		};
+		
+		type = g_type_register_static (PARENT_TYPE, "GdaDataModelRow", &info, G_TYPE_FLAG_ABSTRACT);
+		g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
 	}
 
 	return type;
@@ -431,9 +429,9 @@ gda_data_model_row_get_access_flags (GdaDataModel *model)
 		GDA_DATA_MODEL_ACCESS_CURSOR_FORWARD |
 		GDA_DATA_MODEL_ACCESS_CURSOR_BACKWARD;
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_ROW (model), FALSE);
-	g_return_val_if_fail (CLASS (model)->is_updatable != NULL, FALSE);
 
 	if (! ((GdaDataModelRow *)model)->priv->read_only &&
+	    CLASS (model)->is_updatable &&
 	    CLASS (model)->is_updatable (GDA_DATA_MODEL_ROW (model)))
 		flags |= GDA_DATA_MODEL_ACCESS_WRITE;
 	
@@ -533,7 +531,6 @@ gda_data_model_row_append_row (GdaDataModel *model, GError **error)
 	gint retval = -1;
 
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_ROW (model), -1);
-	g_return_val_if_fail (row != NULL, -1);
 	g_return_val_if_fail (CLASS (model)->append_row != NULL, -1);
 
 	if (((GdaDataModelRow *)model)->priv->read_only) {
