@@ -116,8 +116,13 @@ gda_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[])
 	/* dictionary DTD */
 	file = gda_gbr_get_file_path (GDA_DATA_DIR, LIBGDA_ABI_NAME, "dtd", "libgda-dict.dtd", NULL);
 	gda_dict_dtd = xmlParseDTD (NULL, (xmlChar*)file);
-	if (gda_dict_dtd)
+	if (gda_dict_dtd) {
+		if(gda_dict_dtd->name) {
+			g_free (gda_dict_dtd->name);
+			gda_dict_dtd->name = NULL;
+		}
 		gda_dict_dtd->name = xmlStrdup((xmlChar*) "gda_dict");
+	}
 	else
 		g_message (_("Could not parse '%s': "
 			     "XML dictionaries validation will not be performed (some weird errors may occur)"),
