@@ -62,7 +62,7 @@ gda_handler_string_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaHandlerStringClass),
 			(GBaseInitFunc) NULL,
