@@ -56,7 +56,7 @@ gda_handler_type_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaHandlerTypeClass),
 			(GBaseInitFunc) NULL,
